#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "audio.h"

static int quit;
static struct au_module *mod;
static const char *fname;

int force_snd_config;


int main(int argc, char **argv)
{
	int i, c, vol;

	for(i=1; i<argc; i++) {
		if(argv[i][0] == '-') {
			if(strcmp(argv[i], "-setup") == 0) {
				force_snd_config = 1;
			} else if(strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "-help") == 0) {
				printf("Usage: %s [options] <file>\n", argv[0]);
				printf("Options:\n");
				printf("  -setup: skip auto-detection and configure sound card\n");
				printf("  -h,-help: print usage and exit\n");
				return 0;
			} else {
				fprintf(stderr, "invalid option: %s\n", argv[i]);
				return 1;
			}
		} else {
			if(fname) {
				fprintf(stderr, "unexpected argument: %s\n", argv[i]);
				return 1;
			}
			fname = argv[i];
		}
	}

	if(!fname) {
		fprintf(stderr, "module file not specified\n");
		return 1;
	}

	/* au_init needs to be called early, before init_timer, and also before
	 * we enter graphics mode, to use the midas configuration tool if necessary
	 */
	if(au_init() == -1) {
		return 1;
	}
	if(!(mod = au_load_module(fname))) {
		au_shutdown();
		return 1;
	}
	au_play_module(mod);

	while(au_module_state(mod) == AU_PLAYING) {
		while(kbhit()) {
			c = getch();
			switch(c) {
			case 27:
				goto break_evloop;
			case '=':
				vol = au_volume(AU_VOLUP);
				printf("vol+: %d\n", vol);
				break;
			case '-':
				vol = au_volume(AU_VOLDN);
				printf("vol-: %d\n", vol);
				break;
			default:
				break;
			}
		}
		au_update();
		printf("pos: %d/%d       \r", au_module_getpos(mod), mod->length);
	}

break_evloop:
	putchar('\n');
	au_shutdown();
	return 0;
}
